/*
 * XdccDownloader - ChannelNames.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import java.util.Collection;

import net.pterodactylus.irc.Connection;
import net.pterodactylus.irc.Nickname;

/**
 * Notifies a listener that a list of nicknames has been retrieved for a
 * channel.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class ChannelNicknames extends AbstractChannelEvent {

	/** The nicknames. */
	private final Collection<Nickname> nicknames;

	/**
	 * Creates a new channel nicknames event.
	 *
	 * @param connection
	 * 		The connection the event occured on
	 * @param channel
	 * 		The channel the nicknames are listed for
	 * @param nicknames
	 * 		The nicknames
	 */
	public ChannelNicknames(Connection connection, String channel, Collection<Nickname> nicknames) {
		super(connection, channel);
		this.nicknames = nicknames;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the nicknames retrieved for the channel.
	 *
	 * @return The nicknames retrieved for the channel
	 */
	public Collection<Nickname> nicknames() {
		return nicknames;
	}

}
