/*
 * XdccDownloader - ResearchCommand.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.ui.stdin;

import static java.util.Arrays.asList;

import java.io.IOException;
import java.io.Writer;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import net.pterodactylus.xdcc.core.Core;
import net.pterodactylus.xdcc.data.Download;

import com.google.common.primitives.Ints;

/**
 * Command that runs a search for the exact filename of a failed download.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class ResearchCommand extends SearchCommand {

	public ResearchCommand(Core core) {
		super(core);
	}

	@Override
	public String getName() {
		return "research";
	}

	@Override
	public Collection<String> getAliases() {
		return asList("rs");
	}

	@Override
	public State execute(State state, List<String> parameters, Writer outputWriter) throws IOException {
		Integer index = Ints.tryParse(parameters.get(0));
		List<Download> lastFailedDownloads = state.getLastFailedDownloads();
		if ((index != null) && (index < lastFailedDownloads.size())) {
			Download failedDownload = lastFailedDownloads.get(index);
			return super.execute(state, asList(failedDownload.pack().name()), outputWriter);
		}
		return super.execute(state, Collections.<String>emptyList(), outputWriter);
	}

}
